pub struct ListPublisherAccountsResponse {
pub account: Option<Vec<PublisherAccount>>,
pub next_page_token: Option<String>,
}Expand description
Response for the publisher account list request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list accounts (response)
Fields
account: Option<Vec<PublisherAccount>>Publisher that the client credentials can access.
next_page_token: Option<String>If not empty, indicates that there might be more accounts for the request; you must pass this value in a new ListPublisherAccountsRequest.